Welcome to AstroDynX's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorials/index
   examples/index
   api/index

==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
